@@ -20,7 +20,6 @@
 #include <QMetaEnum>
 
 #include <KColorUtils>
-#include <KDirWatch>
 #include <KSharedConfig>
 #include <kpluginmetadata.h>
 
@@ -38,17 +37,18 @@ ImageSetPrivate *ImageSetPrivate::globalImageSet = nullptr;
 QHash<QString, ImageSetPrivate *> ImageSetPrivate::themes = QHash<QString, ImageSetPrivate *>();
 using QSP = QStandardPaths;
 
-KSharedConfig::Ptr configForImageSet(const QString &basePath, const QString &theme)
+QString configFileForImageSet(const QString &basePath, const QString &theme)
 {
     const QString baseName = basePath % theme;
     QString configPath = QSP::locate(QSP::GenericDataLocation, baseName + QLatin1String("/config"));
     if (!configPath.isEmpty()) {
-        return KSharedConfig::openConfig(configPath, KConfig::SimpleConfig);
+        return configPath;
     }
     QString metadataPath = QSP::locate(QSP::GenericDataLocation, baseName + QLatin1String("/metadata.desktop"));
-    return KSharedConfig::openConfig(metadataPath, KConfig::SimpleConfig);
+    return metadataPath;
 }
 
+#if KSVG_BUILD_DEPRECATED_SINCE(6, 21)
 KPluginMetaData metaDataForImageSet(const QString &basePath, const QString &theme)
 {
     QString packageBasePath = basePath % theme;
@@ -71,16 +71,19 @@ KPluginMetaData metaDataForImageSet(const QString &basePath, const QString &them
         for (const QString &key : cg.keyList()) {
             obj[key] = cg.readEntry(key);
         }
-        qWarning(LOG_KSVG) << "The theme" << theme << "uses the legacy metadata.desktop. Consider contacting the author and asking them update it to use the newer JSON format.";
+        qWarning(LOG_KSVG) << "The theme" << theme
+                           << "uses the legacy metadata.desktop. Consider contacting the author and asking them update it to use the newer JSON format.";
         return KPluginMetaData(obj, packageBasePath + QLatin1String("/metadata.desktop"));
     } else {
         qCWarning(LOG_KSVG) << "Could not locate metadata for theme" << theme;
         return {};
     }
 }
+#endif
 
-ImageSetPrivate::ImageSetPrivate(QObject *parent)
+ImageSetPrivate::ImageSetPrivate(const QString &_basePath, QObject *parent)
     : QObject(parent)
+    , basePath(_basePath)
     , colorScheme(QPalette::Active, KColorScheme::Window, KSharedConfigPtr(nullptr))
     , selectionColorScheme(QPalette::Active, KColorScheme::Selection, KSharedConfigPtr(nullptr))
     , buttonColorScheme(QPalette::Active, KColorScheme::Button, KSharedConfigPtr(nullptr))
@@ -91,26 +94,26 @@ ImageSetPrivate::ImageSetPrivate(QObject *parent)
     , pixmapCache(nullptr)
     , cacheSize(DEFAULT_CACHE_SIZE)
     , cachesToDiscard(NoCache)
-    , isDefault(true)
+#if KSVG_BUILD_DEPRECATED_SINCE(6, 21)
     , useGlobal(true)
+#endif
     , cacheImageSet(true)
-    , fixedName(false)
-    , apiMajor(1)
-    , apiMinor(0)
-    , apiRevision(0)
 {
-    const QString org = QCoreApplication::organizationName();
-    if (!org.isEmpty()) {
-        basePath += u'/' + org;
-    }
-    const QString appName = QCoreApplication::applicationName();
-    if (!appName.isEmpty()) {
-        basePath += u'/' + appName;
-    }
     if (basePath.isEmpty()) {
-        basePath = QStringLiteral("ksvg");
+        const QString org = QCoreApplication::organizationName();
+        if (!org.isEmpty()) {
+            basePath += u'/' + org;
+        }
+        const QString appName = QCoreApplication::applicationName();
+        if (!appName.isEmpty()) {
+            basePath += u'/' + appName;
+        }
+        if (basePath.isEmpty()) {
+            basePath = QStringLiteral("ksvg");
+        }
+        basePath += u"/svgtheme/";
     }
-    basePath += u"/svgtheme/";
+
     pixmapSaveTimer = new QTimer(this);
     pixmapSaveTimer->setSingleShot(true);
     pixmapSaveTimer->setInterval(600);
@@ -123,9 +126,9 @@ ImageSetPrivate::ImageSetPrivate(QObject *parent)
 
     QCoreApplication::instance()->installEventFilter(this);
 
-    #if defined(Q_OS_LINUX)
+#if defined(Q_OS_LINUX)
     struct sysinfo x;
-    if (sysinfo(&x) == 0)  {
+    if (sysinfo(&x) == 0) {
         bootTime = QDateTime::currentSecsSinceEpoch() - x.uptime;
         qCDebug(LOG_KSVG) << "ImageSetPrivate: Using boot time value" << bootTime;
     } else {
@@ -133,7 +136,7 @@ ImageSetPrivate::ImageSetPrivate(QObject *parent)
         bootTime = QDateTime::currentSecsSinceEpoch();
         qCWarning(LOG_KSVG) << "ImageSetPrivate: Failed to get uptime from sysinfo. Using current time as boot time" << bootTime;
     }
-    #endif
+#endif
 }
 
 ImageSetPrivate::~ImageSetPrivate()
@@ -155,11 +158,7 @@ bool ImageSetPrivate::useCache()
         // clear any cached values from the previous theme cache
         themeVersion.clear();
 
-        if (!themeMetadataPath.isEmpty()) {
-            KDirWatch::self()->removeFile(themeMetadataPath);
-        }
-
-        themeMetadataPath = configForImageSet(basePath, imageSetName)->name();
+        const QString themeMetadataPath = configFileForImageSet(basePath, imageSetName);
         const QString cacheFileBase = cacheFile + QLatin1String("*.kcache");
 
         QString currentCacheFileName;
@@ -202,10 +201,8 @@ bool ImageSetPrivate::useCache()
             if (!cacheFilePath.isEmpty()) {
                 const QFileInfo cacheFileInfo(cacheFilePath);
                 const QFileInfo metadataFileInfo(themeMetadataPath);
-                const QFileInfo iconImageSetMetadataFileInfo(iconImageSetMetadataPath);
 
-                cachesTooOld = (cacheFileInfo.lastModified().toSecsSinceEpoch() < metadataFileInfo.lastModified().toSecsSinceEpoch())
-                    || (cacheFileInfo.lastModified().toSecsSinceEpoch() < iconImageSetMetadataFileInfo.lastModified().toSecsSinceEpoch());
+                cachesTooOld = (cacheFileInfo.lastModified().toSecsSinceEpoch() < metadataFileInfo.lastModified().toSecsSinceEpoch());
             }
         }
 
@@ -324,7 +321,6 @@ void ImageSetPrivate::colorsChanged()
     headerColorScheme = KColorScheme(QPalette::Active, KColorScheme::Header, colors);
     tooltipColorScheme = KColorScheme(QPalette::Active, KColorScheme::Tooltip, colors);
     scheduleImageSetChangeNotification(PixmapCache | SvgElementsCache);
-    Q_EMIT applicationPaletteChange();
 }
 
 void ImageSetPrivate::scheduleImageSetChangeNotification(CacheTypes caches)
@@ -620,19 +616,19 @@ bool ImageSetPrivate::findInCache(const QString &key, QPixmap &pix, unsigned int
         qCDebug(LOG_KSVG) << "ImageSetPrivate::findInCache: lastModified > cacheLastModifiedTime for" << key;
         return false;
     }
-    #if defined(Q_OS_LINUX)
+#if defined(Q_OS_LINUX)
     // If the timestamp is the UNIX epoch (0)  then we compare against the boot time instead.
     // This is notably the case on ostree based systems such as Fedora Kinoite.
     if (lastModified == 0 && bootTime > cacheLastModifiedTime) {
         qCDebug(LOG_KSVG) << "ImageSetPrivate::findInCache: lastModified == 0 && bootTime > cacheLastModifiedTime for" << key;
         return false;
     }
-    #else
+#else
     if (lastModified == 0) {
         qCWarning(LOG_KSVG) << "findInCache with a lastModified timestamp of 0 is deprecated";
         return false;
     }
-    #endif
+#endif
 
     qCDebug(LOG_KSVG) << "ImageSetPrivate::findInCache: using cache for" << key;
     const QString id = keysToCache.value(key);
@@ -721,43 +717,11 @@ void ImageSetPrivate::setImageSetName(const QString &tempImageSetName, bool emit
     headerColorScheme = KColorScheme(QPalette::Active, KColorScheme::Header, colors);
     tooltipColorScheme = KColorScheme(QPalette::Active, KColorScheme::Tooltip, colors);
 
+    fallbackImageSets = {QLatin1String(ImageSetPrivate::defaultImageSet)};
+
+#if KSVG_BUILD_DEPRECATED_SINCE(6, 21)
     pluginMetaData = metaDataForImageSet(basePath, theme);
-    KSharedConfigPtr metadata = configForImageSet(basePath, theme);
-
-    KConfigGroup cg(metadata, QStringLiteral("Settings"));
-    QString fallback = cg.readEntry("FallbackImageSet", QString());
-
-    fallbackImageSets.clear();
-    while (!fallback.isEmpty() && !fallbackImageSets.contains(fallback)) {
-        fallbackImageSets.append(fallback);
-
-        KSharedConfigPtr metadata = configForImageSet(basePath, fallback);
-        KConfigGroup cg(metadata, QStringLiteral("Settings"));
-        fallback = cg.readEntry("FallbackImageSet", QString());
-    }
-
-    if (!fallbackImageSets.contains(QLatin1String(ImageSetPrivate::defaultImageSet))) {
-        fallbackImageSets.append(QLatin1String(ImageSetPrivate::defaultImageSet));
-    }
-
-    // Check for what Plasma version the theme has been done
-    // There are some behavioral differences between KDE4 Plasma and Plasma 5
-    const QString apiVersion = pluginMetaData.value(QStringLiteral("X-Plasma-API"));
-    apiMajor = 1;
-    apiMinor = 0;
-    apiRevision = 0;
-    if (!apiVersion.isEmpty()) {
-        const QList<QStringView> parts = QStringView(apiVersion).split(QLatin1Char('.'));
-        if (!parts.isEmpty()) {
-            apiMajor = parts.value(0).toInt();
-        }
-        if (parts.count() > 1) {
-            apiMinor = parts.value(1).toInt();
-        }
-        if (parts.count() > 2) {
-            apiRevision = parts.value(2).toInt();
-        }
-    }
+#endif
 
     if (emitChanged) {
         scheduleImageSetChangeNotification(PixmapCache | SvgElementsCache);
